"""
offline
======
This module provides offline functionality.
"""
from .offline import (
    download_plotlyjs,
    get_plotlyjs_version,
    get_plotlyjs,
    enable_mpl_offline,
    init_notebook_mode,
    iplot,
    iplot_mpl,
    plot,
    plot_mpl,
)
